Kaidoku: Player, solver and creater of sudoku puzzles
=======================

Kaidoku can solve sudoku puzzles, play with the puzzles and create sudoku puzzles from command-line interface. Kaidoku is a

- player of sudoku. You can play original sudoku puzzles in various level of difficulty with command line interface. You can get hints when you want.
- solver of sudoku. It can solve sudoku puzzles. It evaluates if a given puzzle is valid sudoku with unique solution, or invalid sudoku with no solution or multiple solutions. It can show the procedure of solving a sudoku puzzle with various logics. Based on the logics required to solve a sudoku puzzle, it identifies the difficulty of the sudoku puzzles for humans to solve.
- creater of sudoku. It can create new sudoku puzzles. The puzzles shipped with this program was created by the program itself.

Following sudoku puzzles were made by this program, and drawn by this program.

.. image:: doc/image/3-1.jpg

.. image:: doc/image/8-1p.jpg

Document
---------------

This is a program in development. Document is to be written at:

https://github.com/sekika/kaidoku/blob/master/doc/README.rst

